(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/common/http'), require('angular-i18next'), require('rxjs/operators'), require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('angular-i18next-error-interceptor', ['exports', '@angular/common/http', 'angular-i18next', 'rxjs/operators', '@angular/core'], factory) :
    (factory((global['angular-i18next-error-interceptor'] = {}),global.ng.common.http,global.angularI18next,global.rxjs.operators,global.ng.core));
}(this, (function (exports,http,angularI18next,operators,core) { 'use strict';

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    /** @type {?} */
    var HTTP_STATUS_DICTIONARY = new core.InjectionToken('HTTP_STATUS_LOCALE_KEYS');

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var I18NextErrorInterceptor = /** @class */ (function () {
        function I18NextErrorInterceptor(injector // https://github.com/angular/angular/issues/18224
        ) {
            this.injector = injector;
            this.statusKeys = this.injector.get(HTTP_STATUS_DICTIONARY);
        }
        /**
         * @param {?} req
         * @param {?} next
         * @return {?}
         */
        I18NextErrorInterceptor.prototype.intercept = /**
         * @param {?} req
         * @param {?} next
         * @return {?}
         */
            function (req, next) {
                var _this = this;
                return next.handle(req).pipe(operators.tap(function (event) { }, function (err) {
                    if (err instanceof http.HttpErrorResponse) {
                        _this.HandleErrorMessage(err);
                    }
                }));
            };
        /**
         * @private
         * @param {?} errorResponse
         * @return {?}
         */
        I18NextErrorInterceptor.prototype.HandleErrorMessage = /**
         * @private
         * @param {?} errorResponse
         * @return {?}
         */
            function (errorResponse) {
                if (!errorResponse) {
                    return errorResponse;
                }
                /** @type {?} */
                var errorEntity;
                // if error is object or json string that can be parsed
                try {
                    if (errorResponse.error instanceof Object) {
                        errorEntity = errorResponse.error;
                    }
                    else {
                        errorEntity = JSON.parse(errorResponse.error);
                    }
                }
                catch (ex) { }
                // if object got message: server localized message by himself (no need to translate)
                if (!(errorEntity && errorEntity.message)) {
                    errorEntity = { message: this.GetLocalizedStatusMessage(errorResponse.status) };
                }
                // modify error response with client localized message
                return new http.HttpErrorResponse(Object.assign(errorResponse, { error: errorEntity }));
            };
        /**
         * @private
         * @param {?=} status
         * @return {?}
         */
        I18NextErrorInterceptor.prototype.GetLocalizedStatusMessage = /**
         * @private
         * @param {?=} status
         * @return {?}
         */
            function (status) {
                if (status === void 0) {
                    status = undefined;
                }
                /** @type {?} */
                var i18nextService = this.injector.get(angularI18next.I18NEXT_SERVICE);
                /** @type {?} */
                var errorKey = this.statusKeys[status] || this.statusKeys.default;
                return i18nextService.t(errorKey);
            };
        I18NextErrorInterceptor.decorators = [
            { type: core.Injectable }
        ];
        /** @nocollapse */
        I18NextErrorInterceptor.ctorParameters = function () {
            return [
                { type: core.Injector }
            ];
        };
        return I18NextErrorInterceptor;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var HttpErrorResponseMessage = /** @class */ (function () {
        function HttpErrorResponseMessage() {
        }
        /**
         * @param {?} httpErrorResp
         * @return {?}
         */
        HttpErrorResponseMessage.prototype.transform = /**
         * @param {?} httpErrorResp
         * @return {?}
         */
            function (httpErrorResp) {
                if (!httpErrorResp || !httpErrorResp.error) {
                    return null;
                }
                return httpErrorResp.error.message;
            };
        HttpErrorResponseMessage.decorators = [
            { type: core.Injectable },
            { type: core.Pipe, args: [{
                        name: 'httpErrorResponseMessage',
                    },] }
        ];
        return HttpErrorResponseMessage;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    /** @type {?} */
    var DEFAULT_STATUS_KEYS = {
        400: 'http_error:validation_error',
        401: 'http_error:not_authorized',
        403: 'http_error:access_denied',
        500: 'http_error:internal_server_error',
        'default': 'http_error:unknown_server_error'
    };
    /** @type {?} */
    var declarations = [
        HttpErrorResponseMessage
    ];
    var I18NextErrorInterceptorModule = /** @class */ (function () {
        function I18NextErrorInterceptorModule() {
        }
        /**
         * @param {?=} httpStatusDictionary
         * @return {?}
         */
        I18NextErrorInterceptorModule.forRoot = /**
         * @param {?=} httpStatusDictionary
         * @return {?}
         */
            function (httpStatusDictionary) {
                if (httpStatusDictionary === void 0) {
                    httpStatusDictionary = null;
                }
                return {
                    ngModule: I18NextErrorInterceptorModule,
                    providers: [
                        {
                            provide: HTTP_STATUS_DICTIONARY,
                            useValue: httpStatusDictionary || DEFAULT_STATUS_KEYS
                        },
                        {
                            provide: http.HTTP_INTERCEPTORS,
                            useClass: I18NextErrorInterceptor,
                            multi: true
                        }
                    ]
                };
            };
        I18NextErrorInterceptorModule.decorators = [
            { type: core.NgModule, args: [{
                        imports: [
                            http.HttpClientModule
                        ],
                        declarations: declarations,
                        exports: declarations,
                        providers: [
                            HttpErrorResponseMessage
                        ]
                    },] }
        ];
        return I18NextErrorInterceptorModule;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */

    exports.HTTP_STATUS_DICTIONARY = HTTP_STATUS_DICTIONARY;
    exports.DEFAULT_STATUS_KEYS = DEFAULT_STATUS_KEYS;
    exports.I18NextErrorInterceptorModule = I18NextErrorInterceptorModule;
    exports.HttpErrorResponseMessage = HttpErrorResponseMessage;
    exports.ɵa = I18NextErrorInterceptor;

    Object.defineProperty(exports, '__esModule', { value: true });

})));

//# sourceMappingURL=angular-i18next-error-interceptor.umd.js.map